==> 1.1.6.tar.gz: example/android/app/src/main/java/com/fusion/fusionsdk_example/SplashActivity.java <==
package com.fusion.fusionsdk_example;

import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.view.ViewGroup;

import androidx.annotation.Nullable;
import androidx.fragment.app.FragmentActivity;

import com.leyou.fusionsdk.FusionAdSDK;
import com.leyou.fusionsdk.ads.splash.SplashAd;
import com.leyou.fusionsdk.ads.splash.SplashAdListener;
import com.leyou.fusionsdk.model.AdCode;


public class SplashActivity extends FragmentActivity implements SplashAdListener {

    private boolean canJump = false;
    private Handler mHandler = new Handler();

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_splash);
        AdCode adCode = new AdCode.Builder()
                .setCodeId("31036284")
                .build();

        ViewGroup adContainer = findViewById(R.id.ad_container);
        FusionAdSDK.loadSplashAd(this, adCode, adContainer, null, this);
    }

    @Override
    public void onSplashAdLoad(SplashAd splashAd) {

    }

    @Override
    public void onAdClicked() {
    }

    @Override
    public void onAdShow() {

    }

    @Override
    public void onAdClosed() {
        next();
    }



    @Override
    public void onError(int i, int i1, String s) {
        mHandler.postDelayed(new Runnable() {
            @Override
            public void run() {
                loadMainActivity();
            }
        }, 2500);
    }


    @Override
    protected void onResume() {
        super.onResume();
        if (canJump) {
            next();
        }
        canJump = true;
    }

    @Override
    protected void onPause() {
        super.onPause();
        canJump = false;
    }

    private void next() {
        if (canJump) {
            loadMainActivity();
        } else {
            canJump = true;
        }
    }

    private void loadMainActivity() {
        startActivity(new Intent(this,MainActivity.class));
        this.finish();
    }
}

==> 1.2.0.tar.gz: example/android/app/src/main/java/com/fusion/fusionsdk_example/SplashActivity.java <==
package com.fusion.fusionsdk_example;

import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.view.ViewGroup;

import androidx.annotation.Nullable;
import androidx.fragment.app.FragmentActivity;

import com.leyou.fusionsdk.FusionAdSDK;
import com.leyou.fusionsdk.ads.splash.SplashAd;
import com.leyou.fusionsdk.ads.splash.SplashAd2;
import com.leyou.fusionsdk.ads.splash.SplashAd2Listener;
import com.leyou.fusionsdk.ads.splash.SplashAdListener;
import com.leyou.fusionsdk.model.AdCode;


public class SplashActivity extends FragmentActivity implements SplashAd2Listener {

    private boolean canJump = false;
    private Handler mHandler = new Handler();
    private ViewGroup adContainer;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_splash);
        AdCode adCode = new AdCode.Builder()
                .setCodeId("31037451")
                .build();
        adContainer = findViewById(R.id.ad_container);
        FusionAdSDK.loadSplashAd2(this, adCode, this);
    }

    @Override
    public void onSplashAdLoad(SplashAd2 splashAd2) {
        if (splashAd2 != null) {
            splashAd2.showAd(adContainer);
        }
    }

    @Override
    public void onAdClicked() {
    }

    @Override
    public void onAdShow() {

    }

    @Override
    public void onAdClosed() {
        next();
    }


    @Override
    public void onError(int i, int i1, String s) {
        mHandler.postDelayed(new Runnable() {
            @Override
            public void run() {
                loadMainActivity();
            }
        }, 2500);
    }


    @Override
    protected void onResume() {
        super.onResume();
        if (canJump) {
            next();
        }
        canJump = true;
    }

    @Override
    protected void onPause() {
        super.onPause();
        canJump = false;
    }

    private void next() {
        if (canJump) {
            loadMainActivity();
        } else {
            canJump = true;
        }
    }

    private void loadMainActivity() {
        startActivity(new Intent(this, MainActivity.class));
        this.finish();
    }
}
